#include <stdio.h>

/*
-----------------------------------------------------------------------------
Program to determine the size in bytes of fundamental C data types
-----------------------------------------------------------------------------
*/

int main ( argc, argv )

int argc;
char *argv[];

{
   int *ptr;

   printf ( "\nLinux Datasizes, v1.0\n" );
   
   printf ( "\n%s %d %s", "The size of char     is", sizeof(char    ), "bytes" );
   printf ( "\n%s %d %s", "The size of short    is", sizeof(short   ), "bytes" );
   printf ( "\n%s %d %s", "The size of int      is", sizeof(int     ), "bytes" );
   printf ( "\n%s %d %s", "The size of long     is", sizeof(long    ), "bytes" );
   printf ( "\n%s %d %s", "The size of unsigned is", sizeof(unsigned), "bytes" );
   printf ( "\n%s %d %s", "The size of ptr      is", sizeof(ptr     ), "bytes" );

   printf ( "\n\n" );
}
